"use strict";(self.webpackChunkkeplergl_jupyter=self.webpackChunkkeplergl_jupyter||[]).push([[7541],{7541:(n,r,t)=>{t.d(r,{Un:()=>i,e2:()=>a,fy:()=>u,hG:()=>c,oz:()=>f,sw:()=>o,zB:()=>l});var e=(0,t(28996).A)(","),o=e.parse,u=e.parseRows,a=e.format,i=e.formatBody,c=e.formatRows,f=e.formatRow,l=e.formatValue},28996:(n,r,t)=>{t.d(r,{A:()=>s});var e={},o={},u=34,a=10,i=13;function c(n){return new Function("d","return {"+n.map((function(n,r){return JSON.stringify(n)+": d["+r+'] || ""'})).join(",")+"}")}function f(n){var r=Object.create(null),t=[];return n.forEach((function(n){for(var e in n)e in r||t.push(r[e]=e)})),t}function l(n,r){var t=n+"",e=t.length;return e<r?new Array(r-e+1).join(0)+t:t}function s(n){var r=new RegExp('["'+n+"\n\r]"),t=n.charCodeAt(0);function s(n,r){var c,f=[],l=n.length,s=0,p=0,h=l<=0,d=!1;function C(){if(h)return o;if(d)return d=!1,e;var r,c,f=s;if(n.charCodeAt(f)===u){for(;s++<l&&n.charCodeAt(s)!==u||n.charCodeAt(++s)===u;);return(r=s)>=l?h=!0:(c=n.charCodeAt(s++))===a?d=!0:c===i&&(d=!0,n.charCodeAt(s)===a&&++s),n.slice(f+1,r-1).replace(/""/g,'"')}for(;s<l;){if((c=n.charCodeAt(r=s++))===a)d=!0;else if(c===i)d=!0,n.charCodeAt(s)===a&&++s;else if(c!==t)continue;return n.slice(f,r)}return h=!0,n.slice(f,l)}for(n.charCodeAt(l-1)===a&&--l,n.charCodeAt(l-1)===i&&--l;(c=C())!==o;){for(var m=[];c!==e&&c!==o;)m.push(c),c=C();r&&null==(m=r(m,p++))||f.push(m)}return f}function p(r,t){return r.map((function(r){return t.map((function(n){return d(r[n])})).join(n)}))}function h(r){return r.map(d).join(n)}function d(n){return null==n?"":n instanceof Date?(o=(t=n).getUTCHours(),u=t.getUTCMinutes(),a=t.getUTCSeconds(),i=t.getUTCMilliseconds(),isNaN(t)?"Invalid Date":((e=t.getUTCFullYear())<0?"-"+l(-e,6):e>9999?"+"+l(e,6):l(e,4))+"-"+l(t.getUTCMonth()+1,2)+"-"+l(t.getUTCDate(),2)+(i?"T"+l(o,2)+":"+l(u,2)+":"+l(a,2)+"."+l(i,3)+"Z":a?"T"+l(o,2)+":"+l(u,2)+":"+l(a,2)+"Z":u||o?"T"+l(o,2)+":"+l(u,2)+"Z":"")):r.test(n+="")?'"'+n.replace(/"/g,'""')+'"':n;var t,e,o,u,a,i}return{parse:function(n,r){var t,e,o=s(n,(function(n,o){if(t)return t(n,o-1);e=n,t=r?function(n,r){var t=c(n);return function(e,o){return r(t(e),o,n)}}(n,r):c(n)}));return o.columns=e||[],o},parseRows:s,format:function(r,t){return null==t&&(t=f(r)),[t.map(d).join(n)].concat(p(r,t)).join("\n")},formatBody:function(n,r){return null==r&&(r=f(n)),p(n,r).join("\n")},formatRows:function(n){return n.map(h).join("\n")},formatRow:h,formatValue:d}}}}]);