(self.webpackChunkkeplergl_jupyter=self.webpackChunkkeplergl_jupyter||[]).push([[2189],{72189:e=>{e.exports=function(e,r){return r||(r=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(r)}}))},e.exports.__esModule=!0,e.exports.default=e.exports}}]);