/*! For license information please see 4754.3dab195e4fde60e442a0.js.LICENSE.txt */
(self.webpackChunkkeplergl_jupyter=self.webpackChunkkeplergl_jupyter||[]).push([[4754,5606,3225],{65606:e=>{var t,r,n=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function c(){throw new Error("clearTimeout has not been defined")}function i(e){if(t===setTimeout)return setTimeout(e,0);if((t===o||!t)&&setTimeout)return t=setTimeout,setTimeout(e,0);try{return t(e,0)}catch(r){try{return t.call(null,e,0)}catch(r){return t.call(this,e,0)}}}!function(){try{t="function"==typeof setTimeout?setTimeout:o}catch(e){t=o}try{r="function"==typeof clearTimeout?clearTimeout:c}catch(e){r=c}}();var u,f=[],s=!1,a=-1;function l(){s&&u&&(s=!1,u.length?f=u.concat(f):a=-1,f.length&&y())}function y(){if(!s){var e=i(l);s=!0;for(var t=f.length;t;){for(u=f,f=[];++a<t;)u&&u[a].run();a=-1,t=f.length}u=null,s=!1,function(e){if(r===clearTimeout)return clearTimeout(e);if((r===c||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(e);try{return r(e)}catch(t){try{return r.call(null,e)}catch(t){return r.call(this,e)}}}(e)}}function m(e,t){this.fun=e,this.array=t}function p(){}n.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)t[r-1]=arguments[r];f.push(new m(e,t)),1!==f.length||s||i(y)},m.prototype.run=function(){this.fun.apply(null,this.array)},n.title="browser",n.browser=!0,n.env={},n.argv=[],n.version="",n.versions={},n.on=p,n.addListener=p,n.once=p,n.off=p,n.removeListener=p,n.removeAllListeners=p,n.emit=p,n.prependListener=p,n.prependOnceListener=p,n.listeners=function(e){return[]},n.binding=function(e){throw new Error("process.binding is not supported")},n.cwd=function(){return"/"},n.chdir=function(e){throw new Error("process.chdir is not supported")},n.umask=function(){return 0}},22799:(e,t)=>{"use strict";var r="function"==typeof Symbol&&Symbol.for,n=r?Symbol.for("react.element"):60103,o=r?Symbol.for("react.portal"):60106,c=r?Symbol.for("react.fragment"):60107,i=r?Symbol.for("react.strict_mode"):60108,u=r?Symbol.for("react.profiler"):60114,f=r?Symbol.for("react.provider"):60109,s=r?Symbol.for("react.context"):60110,a=r?Symbol.for("react.async_mode"):60111,l=r?Symbol.for("react.concurrent_mode"):60111,y=r?Symbol.for("react.forward_ref"):60112,m=r?Symbol.for("react.suspense"):60113,p=r?Symbol.for("react.suspense_list"):60120,d=r?Symbol.for("react.memo"):60115,h=r?Symbol.for("react.lazy"):60116,b=r?Symbol.for("react.block"):60121,S=r?Symbol.for("react.fundamental"):60117,$=r?Symbol.for("react.responder"):60118,w=r?Symbol.for("react.scope"):60119;function T(e){if("object"==typeof e&&null!==e){var t=e.$$typeof;switch(t){case n:switch(e=e.type){case a:case l:case c:case u:case i:case m:return e;default:switch(e=e&&e.$$typeof){case s:case y:case h:case d:case f:return e;default:return t}}case o:return t}}}function g(e){return T(e)===l}t.AsyncMode=a,t.ConcurrentMode=l,t.ContextConsumer=s,t.ContextProvider=f,t.Element=n,t.ForwardRef=y,t.Fragment=c,t.Lazy=h,t.Memo=d,t.Portal=o,t.Profiler=u,t.StrictMode=i,t.Suspense=m,t.isAsyncMode=function(e){return g(e)||T(e)===a},t.isConcurrentMode=g,t.isContextConsumer=function(e){return T(e)===s},t.isContextProvider=function(e){return T(e)===f},t.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===n},t.isForwardRef=function(e){return T(e)===y},t.isFragment=function(e){return T(e)===c},t.isLazy=function(e){return T(e)===h},t.isMemo=function(e){return T(e)===d},t.isPortal=function(e){return T(e)===o},t.isProfiler=function(e){return T(e)===u},t.isStrictMode=function(e){return T(e)===i},t.isSuspense=function(e){return T(e)===m},t.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===c||e===l||e===u||e===i||e===m||e===p||"object"==typeof e&&null!==e&&(e.$$typeof===h||e.$$typeof===d||e.$$typeof===f||e.$$typeof===s||e.$$typeof===y||e.$$typeof===S||e.$$typeof===$||e.$$typeof===w||e.$$typeof===b)},t.typeOf=T},44363:(e,t,r)=>{"use strict";e.exports=r(22799)}}]);